You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:16:39 UTC

svn commit: r527232 [23/28] - in /incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/ajax/ main/java/org/apache/wicket/ajax/calldecorator/ ma...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePage_8.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePage_8.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePage_8.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePage_8.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePage_8.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePage_8.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePage_8.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.basic;
+package org.apache.wicket.markup.html.basic;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePage_9.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePage_9.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePage_9.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePage_9.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePage_9.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePage_9.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePage_9.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.basic;
+package org.apache.wicket.markup.html.basic;
 
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePanel.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePanel.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePanel.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePanel.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePanel.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.basic;
+package org.apache.wicket.markup.html.basic;
 
-import wicket.markup.html.panel.Panel;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.panel.Panel;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePanel_6.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePanel_6.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePanel_6.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePanel_6.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePanel_6.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimplePanel_6.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimplePanel_6.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.basic;
+package org.apache.wicket.markup.html.basic;
 
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.panel.Panel;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.panel.Panel;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClass.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClass.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClass.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClass.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClass.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClass.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClass.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.basic;
+package org.apache.wicket.markup.html.basic;
 
-import wicket.PageParameters;
-import wicket.markup.html.WebPage;
-import wicket.markup.html.form.Form;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClassTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClassTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClassTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClassTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClassTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClassTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/basic/SimpleResponsePageClassTest.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.basic;
+package org.apache.wicket.markup.html.basic;
+
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.protocol.http.MockHttpServletRequest;
+import org.apache.wicket.util.tester.WicketTester;
 
 import junit.framework.TestCase;
-import wicket.markup.html.form.Form;
-import wicket.protocol.http.MockHttpServletRequest;
-import wicket.util.tester.WicketTester;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderComponent1.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderComponent1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderComponent1.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderComponent1.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderComponent1.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderComponent1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderComponent1.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
+
+import org.apache.wicket.markup.html.border.Border;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderComponent2.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderComponent2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderComponent2.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderComponent2.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderComponent2.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderComponent2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderComponent2.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
+
+import org.apache.wicket.markup.html.border.Border;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderRenderWrappedTestPage_1.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderRenderWrappedTestPage_1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderRenderWrappedTestPage_1.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderRenderWrappedTestPage_1.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderRenderWrappedTestPage_1.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderRenderWrappedTestPage_1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderRenderWrappedTestPage_1.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.form.TextField;
-import wicket.markup.html.image.Image;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.border.BoxBorder;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.markup.html.image.Image;
 
 /**
  * Mock page for testing.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderTestHierarchyPage_4.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderTestHierarchyPage_4.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderTestHierarchyPage_4.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderTestHierarchyPage_4.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderTestHierarchyPage_4.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BorderTestHierarchyPage_4.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BorderTestHierarchyPage_4.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTest.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
+
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.MarkupException;
+import org.apache.wicket.markup.html.border.Border;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.protocol.http.MockHttpServletRequest;
 
-import wicket.WicketTestCase;
-import wicket.markup.MarkupException;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.TextField;
-import wicket.protocol.http.MockHttpServletRequest;
 
 /**
  * Test the component: PageView

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_1.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_1.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_1.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_1.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_1.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_2.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_2.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_2.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_2.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_2.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.form.TextField;
-import wicket.markup.html.image.Image;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.border.BoxBorder;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.markup.html.image.Image;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_3.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_3.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_3.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_3.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_3.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_3.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_3.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.form.TextField;
-import wicket.model.PropertyModel;
-import wicket.util.value.ValueMap;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.border.Border;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.model.PropertyModel;
+import org.apache.wicket.util.value.ValueMap;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_5.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_5.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_5.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_5.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_5.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_5.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_5.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_6.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_6.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_6.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_6.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_6.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_6.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/BoxBorderTestPage_6.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.border.Border;
+import org.apache.wicket.markup.html.border.BoxBorder;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/FormBorder.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/FormBorder.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/FormBorder.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/FormBorder.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/FormBorder.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/FormBorder.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/FormBorder.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
 
-import wicket.Component;
-import wicket.MarkupContainer;
-import wicket.markup.html.form.Form;
+import org.apache.wicket.Component;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.markup.html.border.Border;
+import org.apache.wicket.markup.html.form.Form;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/MyApplicationBorder.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/MyApplicationBorder.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/MyApplicationBorder.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/MyApplicationBorder.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/MyApplicationBorder.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/border/MyApplicationBorder.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/border/MyApplicationBorder.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.border;
+package org.apache.wicket.markup.html.border;
+
+import org.apache.wicket.markup.html.border.Border;
+import org.apache.wicket.markup.html.border.BoxBorder;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/debug/WicketComponentTreeTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/debug/WicketComponentTreeTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/debug/WicketComponentTreeTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/debug/WicketComponentTreeTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/debug/WicketComponentTreeTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/debug/WicketComponentTreeTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/debug/WicketComponentTreeTest.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.debug;
+package org.apache.wicket.markup.html.debug;
 
-import wicket.WicketTestCase;
+import org.apache.wicket.WicketTestCase;
 
 /**
  * Test the component: PageView

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/debug/WicketComponentTreeTestPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/debug/WicketComponentTreeTestPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/debug/WicketComponentTreeTestPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/debug/WicketComponentTreeTestPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/debug/WicketComponentTreeTestPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/debug/WicketComponentTreeTestPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/debug/WicketComponentTreeTestPage.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.debug;
+package org.apache.wicket.markup.html.debug;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.debug.PageView;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/AbstractCheckGroupTestPage.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/AbstractCheckGroupTestPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/AbstractCheckGroupTestPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/AbstractCheckGroupTestPage.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/AbstractCheckGroupTestPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/AbstractCheckGroupTestPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/AbstractCheckGroupTestPage.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.io.Serializable;
 import java.util.List;
 
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.WebPage;
-import wicket.model.Model;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Check;
+import org.apache.wicket.markup.html.form.CheckGroup;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.model.Model;
+
 
 /**
  * Tests rendering of the CheckGroup and Check components

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupDisabledTestPage.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupDisabledTestPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupDisabledTestPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupDisabledTestPage.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupDisabledTestPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupDisabledTestPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupDisabledTestPage.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.WebPage;
-import wicket.model.Model;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Check;
+import org.apache.wicket.markup.html.form.CheckGroup;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.model.Model;
+
 
 /**
  * Tests rendering of the CheckGroup and Check components

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -22,13 +22,17 @@
 import java.util.List;
 import java.util.Set;
 
-import wicket.RequestCycle;
-import wicket.WicketRuntimeException;
-import wicket.WicketTestCase;
-import wicket.markup.html.WebMarkupContainer;
-import wicket.model.CompoundPropertyModel;
-import wicket.model.Model;
-import wicket.protocol.http.MockPage;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.form.Check;
+import org.apache.wicket.markup.html.form.CheckGroup;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.model.CompoundPropertyModel;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.protocol.http.MockPage;
+
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage1.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage1.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage1.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage1.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage1.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.ArrayList;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage2.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage2.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage2.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage2.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage2.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.Arrays;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage3.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage3.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage3.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage3.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage3.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage3.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage3.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.Arrays;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage4.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage4.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage4.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage4.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage4.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage4.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage4.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.Arrays;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage5.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage5.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage5.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage5.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage5.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage5.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/CheckGroupTestPage5.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.WebPage;
-import wicket.model.Model;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Check;
+import org.apache.wicket.markup.html.form.CheckGroup;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.model.Model;
+
 
 /**
  * tests exception when check is outside any group

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/FormMethodTestPage.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/FormMethodTestPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/FormMethodTestPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/FormMethodTestPage.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/FormMethodTestPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/FormMethodTestPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/FormMethodTestPage.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
 
 /**
  * @author dashorst

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/FormTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/FormTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/FormTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/FormTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/FormTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/FormTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/FormTest.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
+
+import org.apache.wicket.Component;
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.FormComponent;
+import org.apache.wicket.markup.html.form.IFormProcessingListener;
 
-import wicket.Component;
-import wicket.WicketTestCase;
 
 /**
  * @author Pekka Enberg

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/PrimitiveTypeRequiredTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/PrimitiveTypeRequiredTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/PrimitiveTypeRequiredTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/PrimitiveTypeRequiredTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/PrimitiveTypeRequiredTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/PrimitiveTypeRequiredTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/PrimitiveTypeRequiredTest.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
+
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.html.form.TextField;
 
-import wicket.WicketRuntimeException;
-import wicket.WicketTestCase;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupDisabledTestPage.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupDisabledTestPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupDisabledTestPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupDisabledTestPage.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupDisabledTestPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupDisabledTestPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupDisabledTestPage.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.WebPage;
-import wicket.model.Model;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.Radio;
+import org.apache.wicket.markup.html.form.RadioGroup;
+import org.apache.wicket.model.Model;
 
 /**
  * Tests rendering of the RadioGroup and Radio components

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTest.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.io.Serializable;
 
-import wicket.RequestCycle;
-import wicket.WicketRuntimeException;
-import wicket.WicketTestCase;
-import wicket.markup.html.WebMarkupContainer;
-import wicket.model.CompoundPropertyModel;
-import wicket.model.Model;
-import wicket.protocol.http.MockPage;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.Radio;
+import org.apache.wicket.markup.html.form.RadioGroup;
+import org.apache.wicket.model.CompoundPropertyModel;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.protocol.http.MockPage;
+
 
 /**
  * Test for RadioGroup and Radio components

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage1.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage1.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage1.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage1.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage1.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.WebPage;
-import wicket.model.Model;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.Radio;
+import org.apache.wicket.markup.html.form.RadioGroup;
+import org.apache.wicket.model.Model;
 
 /**
  * Tests rendering of the RadioGroup and Radio components

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage2.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage2.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage2.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage2.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage2.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.WebPage;
-import wicket.model.Model;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.Radio;
+import org.apache.wicket.markup.html.form.RadioGroup;
+import org.apache.wicket.model.Model;
 
 /**
  * Tests rendering of the RadioGroup and Radio components

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage3.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage3.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage3.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage3.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage3.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage3.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/RadioGroupTestPage3.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.Radio;
-import wicket.markup.html.form.RadioGroup;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.Radio;
+import org.apache.wicket.markup.html.form.RadioGroup;
 
 /**
  * Test page for checking markup of radiogroups.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/ValidatorPropertiesTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/ValidatorPropertiesTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/ValidatorPropertiesTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/ValidatorPropertiesTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/ValidatorPropertiesTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/ValidatorPropertiesTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/ValidatorPropertiesTest.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.MissingResourceException;
 
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.properties.MyTesterApplication;
+import org.apache.wicket.properties.TestPage;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.util.tester.WicketTester;
+
 import junit.framework.TestCase;
-import wicket.markup.html.form.Form;
-import wicket.properties.MyTesterApplication;
-import wicket.properties.TestPage;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.util.tester.WicketTester;
 
 /**
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/encryption/CryptTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/encryption/CryptTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/encryption/CryptTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/encryption/CryptTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/encryption/CryptTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/encryption/CryptTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/encryption/CryptTest.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.encryption;
+package org.apache.wicket.markup.html.form.encryption;
+
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.util.crypt.ICrypt;
+import org.apache.wicket.util.crypt.NoCrypt;
+import org.apache.wicket.util.crypt.SunJceCrypt;
 
-import wicket.WicketTestCase;
-import wicket.util.crypt.ICrypt;
-import wicket.util.crypt.NoCrypt;
-import wicket.util.crypt.SunJceCrypt;
 
 /**
  * @author Juergen Donnerstag

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/InterceptTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/InterceptTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/InterceptTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/InterceptTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/InterceptTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/InterceptTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/InterceptTest.java Tue Apr 10 11:15:14 2007
@@ -14,25 +14,26 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.login;
+package org.apache.wicket.markup.html.form.login;
 
 import javax.servlet.http.HttpServletResponse;
 
+import org.apache.wicket.Component;
+import org.apache.wicket.ISessionFactory;
+import org.apache.wicket.Request;
+import org.apache.wicket.Response;
+import org.apache.wicket.RestartResponseAtInterceptPageException;
+import org.apache.wicket.Session;
+import org.apache.wicket.authorization.Action;
+import org.apache.wicket.authorization.IAuthorizationStrategy;
+import org.apache.wicket.protocol.http.WebApplication;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.protocol.http.WebResponse;
+import org.apache.wicket.protocol.http.WebSession;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.tester.WicketTester;
+
 import junit.framework.TestCase;
-import wicket.Component;
-import wicket.ISessionFactory;
-import wicket.Request;
-import wicket.Response;
-import wicket.RestartResponseAtInterceptPageException;
-import wicket.Session;
-import wicket.authorization.Action;
-import wicket.authorization.IAuthorizationStrategy;
-import wicket.protocol.http.WebApplication;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.protocol.http.WebResponse;
-import wicket.protocol.http.WebSession;
-import wicket.util.string.Strings;
-import wicket.util.tester.WicketTester;
 
 
 /**
@@ -149,7 +150,7 @@
 
 		/**
 		 * 
-		 * @see wicket.ISessionFactory#newSession(Request, Response)
+		 * @see org.apache.wicket.ISessionFactory#newSession(Request, Response)
 		 */
 		public Session newSession(Request request, Response resposne)
 		{
@@ -206,7 +207,7 @@
 	private static class MyAuthorizationStrategy implements IAuthorizationStrategy
 	{
 		/**
-		 * @see wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
+		 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
 		 */
 		public boolean isInstantiationAuthorized(Class componentClass)
 		{
@@ -219,8 +220,8 @@
 		}
 
 		/**
-		 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(wicket.Component,
-		 *      wicket.authorization.Action)
+		 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isActionAuthorized(org.apache.wicket.Component,
+		 *      org.apache.wicket.authorization.Action)
 		 */
 		public boolean isActionAuthorized(Component component, Action action)
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/MockHomePage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/MockHomePage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/MockHomePage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/MockHomePage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/MockHomePage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/MockHomePage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/MockHomePage.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.login;
+package org.apache.wicket.markup.html.form.login;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Session;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.form.login.InterceptTest.MySession;
+import org.apache.wicket.markup.html.link.PageLink;
 
-import wicket.Session;
-import wicket.markup.html.WebPage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.form.login.InterceptTest.MySession;
-import wicket.markup.html.link.PageLink;
 
 /**
  * @author marrink

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/MockLoginPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/MockLoginPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/MockLoginPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/MockLoginPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/MockLoginPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/MockLoginPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/MockLoginPage.java Tue Apr 10 11:15:14 2007
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.login;
+package org.apache.wicket.markup.html.form.login;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Application;
+import org.apache.wicket.Session;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.markup.html.form.login.InterceptTest.MySession;
+import org.apache.wicket.model.Model;
 
-import wicket.Application;
-import wicket.Session;
-import wicket.markup.html.WebPage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.TextField;
-import wicket.markup.html.form.login.InterceptTest.MySession;
-import wicket.model.Model;
 
 /**
  * @author marrink

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/PageA.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/PageA.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/PageA.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/PageA.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/PageA.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/login/PageA.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/login/PageA.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.login;
+package org.apache.wicket.markup.html.form.login;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 /**
  * @author marrink

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterTest.java Tue Apr 10 11:15:14 2007
@@ -14,23 +14,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.persistence;
+package org.apache.wicket.markup.html.form.persistence;
 
 import java.util.List;
 
 import javax.servlet.http.Cookie;
 
+import org.apache.wicket.Page;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.markup.html.form.persistence.CookieValuePersister;
+import org.apache.wicket.markup.html.form.persistence.CookieValuePersisterTestPage.TestForm;
+import org.apache.wicket.protocol.http.MockHttpServletRequest;
+import org.apache.wicket.protocol.http.MockHttpServletResponse;
+import org.apache.wicket.protocol.http.WebRequest;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.protocol.http.WebResponse;
+import org.apache.wicket.util.tester.WicketTester;
+
 import junit.framework.TestCase;
-import wicket.Page;
-import wicket.RequestCycle;
-import wicket.markup.html.form.TextField;
-import wicket.markup.html.form.persistence.CookieValuePersisterTestPage.TestForm;
-import wicket.protocol.http.MockHttpServletRequest;
-import wicket.protocol.http.MockHttpServletResponse;
-import wicket.protocol.http.WebRequest;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.protocol.http.WebResponse;
-import wicket.util.tester.WicketTester;
 
 /**
  * How to test CookieValuePersister. Problem: CookieValuePersister relies on

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterTestPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTestPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterTestPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTestPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterTestPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTestPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterTestPage.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.persistence;
+package org.apache.wicket.markup.html.form.persistence;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.TextField;
-import wicket.markup.html.panel.FeedbackPanel;
-import wicket.model.Model;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.markup.html.panel.FeedbackPanel;
+import org.apache.wicket.model.Model;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/FileUploadFieldTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadFieldTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/FileUploadFieldTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadFieldTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/FileUploadFieldTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadFieldTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/FileUploadFieldTest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.upload;
+package org.apache.wicket.markup.html.form.upload;
 
 import java.io.BufferedOutputStream;
 import java.io.FileOutputStream;
@@ -22,14 +22,17 @@
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import wicket.Page;
-import wicket.RequestCycle;
-import wicket.WicketTestCase;
-import wicket.protocol.http.MockHttpServletRequest;
-import wicket.protocol.http.servlet.MultipartServletWebRequest;
-import wicket.util.file.File;
-import wicket.util.lang.Bytes;
-import wicket.util.tester.ITestPageSource;
+import org.apache.wicket.Page;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.html.form.upload.FileUpload;
+import org.apache.wicket.markup.html.form.upload.FileUploadField;
+import org.apache.wicket.protocol.http.MockHttpServletRequest;
+import org.apache.wicket.protocol.http.servlet.MultipartServletWebRequest;
+import org.apache.wicket.util.file.File;
+import org.apache.wicket.util.lang.Bytes;
+import org.apache.wicket.util.tester.ITestPageSource;
+
 
 /**
  * Test of FileUploadField
@@ -85,7 +88,7 @@
 			// We create a temp file because we don't want to depend on a file we might not
 			// know the path of (e.g. the big DTD this test used previously). This enables
 			// us to run the test out of a JAR file if need be, and also with an unknown
-			// running directory (e.g. when run from wicket-parent).
+			// running directory (e.g. when run from org.apache.wicket-parent).
 			tmp = new File(File.createTempFile(this.getClass().getName(), ".txt"));
 			OutputStream os = new BufferedOutputStream(new FileOutputStream(tmp));
 			for (int i = 0; i < 1000; i++)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/FileUploadTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/FileUploadTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/FileUploadTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/FileUploadTest.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.upload;
+package org.apache.wicket.markup.html.form.upload;
 
 import java.io.InputStream;
 import java.lang.reflect.Field;
 import java.util.List;
 
-import wicket.WicketTestCase;
-import wicket.util.upload.DiskFileItemFactory;
-import wicket.util.upload.FileItem;
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.html.form.upload.FileUpload;
+import org.apache.wicket.util.upload.DiskFileItemFactory;
+import org.apache.wicket.util.upload.FileItem;
+
 
 /**
  * Test of FileUpload

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/MockPageWithFormAndUploadField.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/MockPageWithFormAndUploadField.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/MockPageWithFormAndUploadField.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/MockPageWithFormAndUploadField.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/MockPageWithFormAndUploadField.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/form/upload/MockPageWithFormAndUploadField.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/form/upload/MockPageWithFormAndUploadField.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.upload;
+package org.apache.wicket.markup.html.form.upload;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
 
 /**
  * Mock page for use in the FileUploadFieldTest

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/BasePanel.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/BasePanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/BasePanel.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/BasePanel.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/BasePanel.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/BasePanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/BasePanel.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.header;
+package org.apache.wicket.markup.html.header;
 
-import wicket.markup.html.panel.Panel;
+import org.apache.wicket.markup.html.panel.Panel;
 
 /**
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/HeaderScopingTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/HeaderScopingTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/HeaderScopingTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/HeaderScopingTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/HeaderScopingTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/HeaderScopingTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/HeaderScopingTest.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.header;
+package org.apache.wicket.markup.html.header;
 
-import wicket.WicketTestCase;
+import org.apache.wicket.WicketTestCase;
 
 /**
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/MyPage.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/MyPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/MyPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/MyPage.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/MyPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/MyPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/MyPage.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.header;
+package org.apache.wicket.markup.html.header;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 /**
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/PanelA.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/PanelA.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/PanelA.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/PanelA.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/PanelA.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/PanelA.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/PanelA.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.header;
+package org.apache.wicket.markup.html.header;
 
 /**
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/PanelB.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/PanelB.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/PanelB.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/PanelB.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/PanelB.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/PanelB.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/PanelB.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.header;
+package org.apache.wicket.markup.html.header;
 
 /**
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/inheritance/AbstractPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/inheritance/AbstractPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/inheritance/AbstractPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/inheritance/AbstractPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/inheritance/AbstractPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/markup/html/header/inheritance/AbstractPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/markup/html/header/inheritance/AbstractPage.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.header.inheritance;
+package org.apache.wicket.markup.html.header.inheritance;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 /**
  * Test page for wicket:head inclusion.
  */
 public abstract class AbstractPage extends WebPage
 {
@@ -14,12 +14,12 @@
 
 /**
- * Test page for wicket:head inclusion.
+ * Test page for org.apache.wicket:head inclusion.
  */
 public abstract class AbstractPage extends WebPage